%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                    %
%    COMMON SETTINGS FOR PLOTS OF THE ATLANTIC ASYMMETRY ANALYSIS    %
%                                                                    %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% AXES POSITION
% +++++++++++++

    % scaling of the figure?
    scale_figure_height = 0.8;
    scale_figure_width  = 1;

    % position of the axes
    x_axes_offset      = 0.02;
    y_axes_offset      = 0.05;
    width_axes_offset  = -0.1;
    height_axes_offset = -0.06;

    % hard-wire axes position
    axes_position = [0.13 0.11 0.725 0.7476];

% COLOURS AND COLORBAR
% ++++++++++++++++++++

    my_white  = [254 254 254]./255;
    my_left   = [0 76 153]./255;
    my_middle = [0 102 204]./255;
    my_right  = [0 255 255]./255;

    my_teal       = [0 149 186]./255;
    my_light_teal = [153 255 255]./255;
    my_dark_teal  = [0 47 84]./255;

    my_blue      = [0 102 204]./255;
    my_dark_blue = [0 51 102]./255;
    my_red       = [255 51 51]./255;
    my_yellow    = [255 255 51]./255;
    my_cyan      = [0 255 255]./255;
    my_purple    = [153 0 153]./255;

    % colorbar handles
    sunset   = <custom colorbar handle for absolute values>;
    plasma   = <custom colorbar handle for absolute values>;
    centered = <custom colorbar handle for differences>;

    % colours to mark negative lags
    lag_colour        = [0.35 0.35 0.35];
    lag_border_colour = my_white;
    lag_stretch_width        = 6;
    lag_stretch_border_width = 9;

% HIGHLIGHT REGIONS
% +++++++++++++++++

    % which background regions to plot? Define longitudinal extent here
    % i.e., mark WAtl, Atl3 in the Atlantic, and Nino4, Nino34, and Nino12
    % in the Pacific
    if strcmp(basin_name,'Pacific')

        % longitudinal boundaries of standard regions
        highlight_regions = [...
                160 210; ...
                190 240; ...
                270 280];

        % and the names of the regions
        region_names = {'Nino4','Nino34','Nino12'};

    else
        highlight_regions = [...
                -40 -20; ...
                -20 0];
        region_names = {'WAtl','Atl3'};
    end

    % y values for the patches; width: 0.25 months, gap: 0.2 months, maximum y value: 12.5
    if strcmp(basin_name,'Pacific')
        highlight_y_values = [11.8 12.05; 12.25 12.5; 11.8 12.05];
    else
        highlight_y_values = [12.25 12.5; 12.25 12.5];
    end

    region_colours = [my_teal; my_light_teal; my_dark_teal];

% MISCELLANEOUS
% +++++++++++++

    % font size
    scale_font_size = 2;

    % size of the significance crosses
    size_significance_marker = 8;

    % line widths for the significance markers
    line_width_significance_markers = 0.5;
    line_width_significance_outline = 4.5;

    % month shorts
    month_ids = {'J','F','M','A','M','J','J','A','S','O','N','D'};

    % mute warning from robust regression
    % query the last warning, including it's ID with
    % w = warning('query','last').
    warn_id = 'stats:statrobustfit:IterationLimit';
