%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                      %
%   COMPARE ORAS4 AND ERSST ATL3 SST   %
%   SETTINGS                           %
%                                      %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

close all;

compare_oras4_ersst_settings;
disp(sprintf('%s-%s, %d-%d',index_name,var_name,start_base,stop_base));

% --------- %
% LOAD DATA %
% --------- %

    data = struct();

    for dataset_name = {all_data{:}}

        dataset_name = char(dataset_name);

        infile = strrep(file_dummy,'@DATASET_NAME@',upper(dataset_name));
        data.(dataset_name) = load(infile);

    end

% ------------------------------------------ %
% CALCULATIONS: SEASONAL CYCLE AND ANOMALIES %
% ------------------------------------------ %

    % calculate seasonal cycles
    seasonal_cycle    = struct(char(all_data{1}),[],char(all_data{2}),[]);
    seasonal_variance = struct(char(all_data{1}),[],char(all_data{2}),[]);
    anomalies         = struct(char(all_data{1}),[],char(all_data{2}),[]);
    cropped           = struct(char(all_data{1}),[],char(all_data{2}),[]);

    for dataset_name = {all_data{:}}

        dataset_name  = char(dataset_name);
        date_vector   = data.(dataset_name).date_vector;

        is_year  = ( ( date_vector(:,1) >= start_base ) & ...
                     ( date_vector(:,1) <= stop_base  ) );

        cropped.(dataset_name) = is_year;

        for month = 1:12

            is_month = ( date_vector(:,2) == month );

            seasonal_cycle.(dataset_name)(month) = ...
                    nanmean(data.(dataset_name).index(is_year & is_month));

            seasonal_variance.(dataset_name)(month) = ...
                    std(data.(dataset_name).index(is_year & is_month));

            anomalies.(dataset_name)(is_month) = ...
                    data.(dataset_name).index(is_month)-...
                    seasonal_cycle.(dataset_name)(month);

        end

    end

    % calculate seasonal correlations
    dataset_1 = char(all_data{1});
    dataset_2 = char(all_data{2});
    dv_1      = data.(dataset_1).date_vector;
    dv_2      = data.(dataset_2).date_vector;
    seasonal_accs = [];

    for month = 1:12

        is_month_1 = ( dv_1(:,2) == month );
        is_month_2 = ( dv_2(:,2) == month );

        series_1 = anomalies.(dataset_1)(cropped.(dataset_1) & is_month_1);
        series_2 = anomalies.(dataset_2)(cropped.(dataset_2) & is_month_2);

        rho = corrcoef(series_1,series_2);

        seasonal_accs(month) = rho(1,2);

    end

    % correlation between the anomalies for all months
    time_series1 = anomalies.(char(all_data{1}))(cropped.(char(all_data{1})));
    time_series2 = anomalies.(char(all_data{2}))(cropped.(char(all_data{2})));

    rho = corrcoef(time_series1,time_series2);
    rho = rho(1,2);

 % ----- %
 % PLOTS %
 % ----- %

%      % SEASONAL CYCLE
%      % ++++++++++++++
%
%          hf = figure;
%          hax_sc = axes('XLim',[0.5 12.5],'XTick',1:12,'XTickLabel',{month_names{:}});
%          hold(hax_sc,'on');
%          grid(hax_sc,'on');
%
%          legend_handles = [];
%          legend_entries = {};
%
%          for dataset_name = {all_data{:}}
%
%              dataset_name = char(dataset_name);
%
%              % background
%              plot(seasonal_cycle.(dataset_name),'-w','LineWidth',4);
%
%              legend_handles(end+1) = plot(seasonal_cycle.(dataset_name),'-',...
%                      'LineWidth',2,'Color',all_colours.(dataset_name));
%
%              legend_entries{end+1} = dataset_name;
%
%          end
%
%          hold(hax_sc,'off');
%
%          h_legend = legend(legend_handles,legend_entries,'Location','SouthOutside');
%          set(h_legend,'Box','off','Orientation','horizontal');
%
%          ylabel(['SC of ',var_name]);
%
%          fig_title = strrep(title_dummy,'@PLOT_TYPE@','Seasonal Cycle');
%          title(fig_title);
%
%          fig_name = strrep(name_dummy,'@PLOT_TYPE@','sc');
%
%          print(res_flag,hf,fig_name,'-dpng');
%          close(hf);
%
     % SEASONAL VARIANCE
     % +++++++++++++++++

        % set up figure
        hf = figure;
        hf.Position = hf.Position.*scale_figure;

        % axes set up
        hax_sc = axes('XLim',[0.5 12.5],'XTick',1:12,'XTickLabel',{month_names{:}},...
                   'YLim',y_limits_stddev.(var_name));

        hold(hax_sc,'on');
        grid(hax_sc,'on');

        % font size
        new_size = floor(hax_sc.FontSize*scale_font_size);
        set(hax_sc,'FontSize',new_size);

        % legend initialization
        legend_handles = [];
        legend_entries = {};

         for c_data = 1:n_data

             dataset_name = char(all_data{c_data});

             % background
             plot(seasonal_variance.(dataset_name),'-w','LineWidth',4);

             legend_handles(end+1) = plot(seasonal_variance.(dataset_name),'-',...
                     'LineWidth',2,'Color',all_colours.(dataset_name));

             legend_entries{end+1} = char(data_names{c_data});

         end

         hold(hax_sc,'off');

         h_legend = legend(legend_handles,legend_entries,'Location','NorthEastOutside');
         set(h_legend,'Box','off','Orientation','vertical');

         % common x-position of the y labels
         h_ylabel_std = ylabel('Std-dev');
         set(h_ylabel_std,...
                 'Units','normalized',...
                 'Position',y_label_position);

         fig_title = strrep(title_dummy,'@PLOT_TYPE@','Seasonal Std-dev');
         title(fig_title);

         % set common axes position
         hax_sc.Position = axes_position;

         fig_name = strrep(name_dummy,'@PLOT_TYPE@','std');

         print(res_flag,hf,fig_name,'-dpng');
         % close(hf);

     % ANOMALIES
     % +++++++++

         hf = figure;
         hf.Position = hf.Position.*scale_figure;

         x_start = datenum([start_anomalies 1 1 0 0 0]);
         x_end   = datenum([stop_anomalies 12 31 23 59 59]);

         hax = axes('XLim',[x_start x_end],'YLim',y_limits_anomalies.(var_name),...
              'Layer','top');

         hold(hax,'on');
         grid(hax,'on');

         % font size
         new_size = floor(hax.FontSize*scale_font_size);
         set(hax,'FontSize',new_size);

         % 0-line and grey shading
         % shading
         % need to shade more than the axes limits
         artificial_start = datenum([start_anomalies-5 1 1 0 0 0]);
         artificial_stop  = datenum([stop_anomalies+5 1 1 0 0 0]);
         x_values = [artificial_start artificial_stop ...
                 artificial_stop artificial_start artificial_start];
         y_values = [hax.YLim(1) hax.YLim(1) 0 0 hax.YLim(1)];

         hpatch = patch(x_values,y_values,my_gray);
         set(hpatch,'EdgeColor','none');

         plot(hax,[artificial_start artificial_stop],[0 0],'Color',hax.XColor);

         legend_handles = [];
         legend_entries = {};

         for c_data = 1:n_data

             dataset_name = char(all_data{c_data});

             is_period = ( ( data.(dataset_name).date_vector(:,1) >= start_anomalies ) & ...
                           ( data.(dataset_name).date_vector(:,1) <= stop_anomalies ));

             x_data = datenum(data.(dataset_name).date_vector(is_period,:));
             y_data = anomalies.(dataset_name)(is_period);

             % background
             plot(hax,x_data,y_data,'-w','LineWidth',4);

             legend_handles(end+1) = plot(hax,x_data,y_data,'-',...
                     'LineWidth',2,'Color',all_colours.(dataset_name));

             legend_entries{end+1} = char(data_names{c_data});

         end

         hold off;

         h_legend = legend(legend_handles,legend_entries,'Location','NorthEastOutside');
         set(h_legend,'Box','off','Orientation','vertical');

         datetick;

         % common x-position of the y-label
         h_ylabel_anomalies = ylabel(['Anomalies']);
         set(h_ylabel_anomalies,...
                 'Units','normalized',...
                 'Position',y_label_position);

         % reset axis limits since datetick kills them
         set(hax,'XLim',[x_start x_end]);

         title_string = ['Anomalies, base: ',num2str(start_base),'-',num2str(stop_base),...
                 ', rho=',num2str(rho,'%1.2f')];

         fig_title = strrep(title_dummy,'@PLOT_TYPE@',title_string);
         title(fig_title);

         % set common axes position
         hax.Position = axes_position;

         fig_name = strrep(name_dummy,'@PLOT_TYPE@','anomalies');

         print(res_flag,hf,fig_name,'-dpng');
         % close(hf);

     % % CROPPED ANOMALIES
     % % +++++++++++++++++
     %
     %     hf = figure;
     %     hold on;
     %     grid on;
     %
     %     legend_handles = [];
     %     legend_entries = {};
     %
     %     for dataset_name = {all_data{:}}
     %
     %         dataset_name = char(dataset_name);
     %         x_data = datenum(data.(dataset_name).date_vector(cropped.(dataset_name),:));
     %         y_data = anomalies.(dataset_name)(cropped.(dataset_name));
     %
     %         % background
     %         plot(x_data,y_data,'-w','LineWidth',4);
     %
     %         legend_handles(end+1) = plot(x_data,y_data,'-',...
     %                 'LineWidth',2,'Color',all_colours.(dataset_name));
     %
     %         legend_entries{end+1} = dataset_name;
     %
     %     end
     %
     %     hold off;
     %
     %     h_legend = legend(legend_handles,legend_entries,'Location','SouthOutside');
     %     set(h_legend,'Box','off','Orientation','horizontal');
     %
     %     datetick;
     %     ylabel([var_name,' anomalies']);
     %
     %     title_string = ['Anomalies,',num2str(start_base),'-',num2str(stop_base),...
     %             ', rho=',num2str(rho,'%1.2f')];
     %
     %     fig_title = strrep(title_dummy,'@PLOT_TYPE@',title_string);
     %     title(fig_title);
     %
     %     fig_name = strrep(name_dummy,'@PLOT_TYPE@','anomalies');
     %
     %     print(res_flag,hf,fig_name,'-dpng');
     %     close(hf);

%      % SEASONAL ACCs
%      % +++++++++++++
%
%          hf = figure;
%          axes(hf,'XLim',[0.5 12.5],'XTick',1:12,'XTickLabel',{month_names{:}},...
%               'YLim',[0 1]);
%          hold on;
%          grid on;
%
%          legend_handles = [];
%          legend_entries = {};
%
%          plot(1:12,seasonal_accs,'-k','LineWidth',2);
%          hold off;
%
%          ylabel([var_name,' ACCs']);
%
%          fig_title = strrep(title_dummy,'@PLOT_TYPE@','Monthly ACCs');
%          title(fig_title);
%
%          fig_name = strrep(name_dummy,'@PLOT_TYPE@','accs');
%
%          print(res_flag,hf,fig_name,'-dpng');
%          close(hf);
