%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                           %
%    DIAGNOSE DECADAL FEEDBACK VARIATIONS   %
%    PLOTS                                  %
%                                           %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

disp('plotting feedback strength differences');

% SET UP FIGURE
% +++++++++++++

    hf  = figure;
    hf.Position(3) = scale_figure_width*hf.Position(3);
    hf.Position(4) = scale_figure_height*hf.Position(4);

    % axes
    hax = axes('XLim',[all_starts(1) all_starts(end)],'YLim',[0.5 12.5],...
            'YTick',1:12,'YTickLabel',{month_ids{:}},...
            'XGrid','on','Layer','top');

    font_size    = floor(hax.FontSize*scale_font_size);
    hax.FontSize = font_size;

    hold(hax,'on');

    % naming the regions
    x_ticks        = [];
    x_tick_labels  = {};

% SET NEGATIVE LAGS TO NAN
% ++++++++++++++++++++++++

    is_negative_lag = ( lag_variations < 0 );
    use_data        = feedback_strengths.positive-feedback_strengths.negative;

    % correct dimensions
    if ( size(is_negative_lag,1) ~= 12 )
        is_negative_lag = is_negative_lag';
    end

    % pick correct feedback strengts and set negative lags to NaN
    use_data(is_negative_lag) = 0;

% PLOT DATA
% +++++++++

    % checkerboard, as in the dynamics analysis
    image(all_starts,[1:12],use_data,'CDataMapping','scaled');
    colorbar(hax);

% POLISHING AND PRINTING
% ++++++++++++++++++++++

    xlabel(hax,'Start year');
    ylabel(hax,'Month');

    % title
    fig_title = strrep(title_dummy,'@ANOMALYTYPE@',basin_name);
    title(hax,fig_title);

    % align axes
    hax.Position = axes_position;

    % colormap and number of displayed colours
    hax.CLim = [-all_diff_limits.(ref_name) all_diff_limits.(ref_name)];
    % diff_cmap = centered(n_colours);
    colormap(centered_cmap);

    % print
    fig_name = strrep(name_dummy,'@ANOMALYTYPE@','differences');
    print(hf,res_flag,fig_name,'-dpng');
    close(hf);
