%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                           %
%    DIAGNOSE DECADAL FEEDBACK VARIATIONS   %
%    SETTINGS                               %
%                                           %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% ----- %
% BASIC %
% ----- %

    % ++++
    % variables names, basin name specified in the wrapper
    % ++++

    % index names
    all_indices = struct('Atlantic',struct(...
                   'ssh', 'Atl3',...
                   'sst', 'Atl3',...
                   'ustr','WAtl'),...
            'Pacific',struct(...
                   'ssh', 'Nino34',...
                   'sst', 'Nino34',...
                   'ustr','Nino4'));

    % time constraints
    start_year     = 1958;
    stop_year      = 2009;

    % for the running analysis: window width?
    % Why 16? Same length as the period 1993-2009.
    window_width = 25; % repeat for 20, 30

    % maximum of lag analysis
    if strcmp(basin_name,'Atlantic')
        maximum_lag = 8;
    else
        maximum_lag = 12;
    end

    % analysis type
    analysis_type = 'rreg';

    % for the bootstrapping
    n_bootstraps = 1000;
    alpha        = 0.1;

% ----- %
% FLAGS %
% ----- %

    % calculations
    perform_calculations = true;
        detrend_data         = false;
        save_data            = perform_calculations;

    % load data that has previously been calculated and saved?
    load_previous_data   = ~save_data;

    % which plots to produce?
    plot_composites      = true;
    plot_differences     = true;

% --------------- %
% FILES AND PATHS %
% --------------- %

    index_path   = '<path where single indices are stored>';
    infile_dummy = [index_path,'@DATASET_NAME@_@VAR_NAME@_@INDEX_NAME@.mat'];

    outpath  = '<path where the output datasets should be stored>';
    out_file = [outpath,...
                'decadal_feedback_variations_',analysis_type,'_ww',num2str(window_width),'_',...
                num2str(start_year),'-',num2str(stop_year),'_',...
                basin_name,'_',...
                all_indices.(basin_name).(ref_name),'-',all_data.(ref_name),'-',ref_name,'_',...
                all_indices.(basin_name).(lag_name),'-',all_data.(lag_name),'-',lag_name,'.mat'];

    % when data is detrended:
    if detrend_data
        out_file = strrep(out_file,'.mat','_detrended.mat');
    end

% ----- %
% OTHER %
% ----- %

    month_names = {'Jan','Feb','Mar','Apr','May','Jun','Jul','Aug','Sep','Oct','Nov','Dec'};

% -------- %
% PLOTTING %
% -------- %

    % GENERAL
    % +++++++

        atlantic_asymmetric_bjf_plot_settings;

        % axes fine tuning
        x_axes_offset      = 0;
        y_axes_offset      = 0.07;
        width_axes_offset  = -0.035;
        height_axes_offset = -0.025;

        axes_position = axes_position+...
                [x_axes_offset y_axes_offset width_axes_offset height_axes_offset];

    % LIMITS ETC
    % ++++++++++

        % colour limits and levels, colormap, colorbar settings
        % for correlations:
        if strcmp(analysis_type,'acc');

            c_limits  = [-1 1];
            n_colours = 20;

        % regressions
        else

            all_c_limits     = struct('ssh',[-25 45],'sst',[-0.03 0.05],'ustr',[-7 12]);  % ssh: 30
            all_diff_limits  = struct('ssh',35,'sst',0.05,'ustr',7);
            all_c_increment  = struct('ssh',2,'sst',0.005,'ustr',1);
            all_n_colours    = struct('ssh',27,'sst',31,'ustr',25);   % ssh: 30
            all_grey_offsets = struct('ssh',4,'sst',2,'ustr',3);

            % what to use?
            c_limits    = all_c_limits.(ref_name);
            c_increment = all_c_increment.(ref_name);
            grey_offset = all_grey_offsets.(ref_name);
            n_colours   = all_n_colours.(ref_name);

        end

    % COLOURMAP
    % +++++++++

        % grey part: omit the lightest third
        n_grey          = length(c_limits(1):c_increment:-c_increment);  % this is the actual number of greys I want to have
        n_grey_complete = floor(3*n_grey/2);                     % this is what the colormap gets to omit the bright parts

        grey_part = gray(n_grey_complete);
        grey_part = flipud(grey_part(grey_offset:n_grey+grey_offset,:));   % here, the darkest patch and the brightest colours are omitted

        % coloured part
        n_coloured = length(0:c_increment:c_limits(2));
        coloured_part = plasma(n_coloured+1);

        % complete colour map -- omit white entry of coloured part
        use_cmap = [grey_part; coloured_part(2:end,:)];

        % set first entry of grey map to white to accomodate NaNs
        use_cmap(1,:) = [1 1 1];

        % ... and the centered cmap for the differences
        centered_cmap = centered(n_colours);

    % NAMING AND OTHERS
    % +++++++++++++++++

        title_dummy = ['@ANOMALYTYPE@ ',upper(ref_name),'-',upper(lag_name)];
        name_dummy  = ['decadal_feedback_variations_',basin_name,...
                '_@ANOMALYTYPE@_',ref_name,'-',lag_name,'_ww',...
                num2str(window_width),'_',num2str(start_year),'-',num2str(stop_year),'.png'];

        % detrending applied?
        if detrend_data
            name_dummy = strrep(name_dummy,'.png','_detrended.png');
        end

        res_flag = '-r300';

% ------------- %
% MISCELLANEOUS %
% ------------- %

    % switch off robust regression warning
    warn_id = 'stats:statrobustfit:IterationLimit';

    % month labelling
    month_ids = {'J','F','M','A','M','J','J','A','S','O','N','D'};
