%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                            %
%   DECADAL VARIATIONS OF EVENT PARAMETERS   %
%   PLOTS                                    %
%                                            %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% ------------ %
% PLOT RESULTS %
% ------------ %

    disp('plotting');

    % need x- and y-placements for image
    x_placements = lon_cover;
    y_placements = [time_axis(1) time_axis(end)];

    % ABSOLUTE STRENGTHS
    % +++++++++++++++++

        for event_type = {'positive','negative'};

            event_type = char(event_type);
            disp(sprintf('\t%s',event_type))

            % data
            use_data = strength_data.(event_type);

            % averaging necessary?
            needs_averaging = ( ndims(use_data) > 2 );
            if needs_averaging
                use_data = nanmean(use_data,3);
            end

            % PREPARATIONS
            % ++++++++++++
                
                hf = figure;
                hf.Position(3) = scale_figure_width*hf.Position(3);
                hf.Position(4) = scale_figure_height*hf.Position(4);

                % axes
                hax = axes('XLim',x_placements,'YLim',y_placements,...
                        'XGrid','on','Layer','top');

                new_font_size = floor(hax.FontSize*scale_font_size);
                set(hax,'FontSize',new_font_size);

                hold(hax,'on');

            % PLOT 
            % ++++
            
                % checkerboard, as in the dynamics analysis
                image(x_placements,y_placements,use_data,'CDataMapping','scaled');

                % display colorbar
                hcb = colorbar(hax);

            % NINO REGIONS 
            % ++++++++++++
            
                % label boxes in a different axis
                hax_labels = axes('XLim',x_placements,'YLim',y_placements,...
                        'Visible','off','FontSize',new_font_size);
                
                hold(hax_labels,'on'); 
    
                for c_region = 1:length(region_names)

                    x_values = [highlight_regions(c_region,1) highlight_regions(c_region,2) ...
                                highlight_regions(c_region,2) highlight_regions(c_region,1) ...
                                highlight_regions(c_region,1)];
                                
                    y_values = [highlight_y_values(c_region,1) highlight_y_values(c_region,1) ...
                                highlight_y_values(c_region,2) highlight_y_values(c_region,2) ...
                                highlight_y_values(c_region,1)];
                    
                    h_patch = patch(x_values,y_values,region_colours(c_region,:),...
                            'EdgeColor','none'); 

                % plot in highlight regions
                end

            % SIGNIFICANCE 
            % ++++++++++++
            
                if needs_averaging

                    for c_start = 1:length(time_axis)

                        use_sigs   = squeeze(is_significant(c_start,:));

                        % ignore NaNs and assume they are not significant
                        use_sigs(isnan(use_sigs)) = false;

                        sig_lons = find(use_sigs);

                        % plot black crosses
                        plot(hax,central_longitudes(sig_lons),...
                                ones(1,length(sig_lons)).*time_axis(c_start),...
                                'x','LineWidth',line_width_significance_outline,...
                                'MarkerSize',size_significance_marker+2,'Color',my_white);

                        plot(hax,central_longitudes(sig_lons),...
                                ones(1,length(sig_lons)).*time_axis(c_start),...
                                'x','LineWidth',line_width_significance_markers,...
                                'MarkerSize',size_significance_marker,'Color',hax.XColor);

                    end

                % if: plot in significant differences for anything but counts
                end

            % POLISHING AND PLOTTING 
            % ++++++++++++++++++++++
            
            ylabel(hax,'Start year');
            xlabel(hax,'\circ lon')

            fig_title = strrep(title_dummy,'@ANOMALYTYPE@',[upper(event_type(1)),event_type(2:end)]);
            h_title = title(hax_labels,fig_title);
            set(h_title,'Visible','on'); 

            % align axes
            % axes_position       = hax_labels.Position+axes_offset;
            hax.Position        = hax.Position+axes_offset;
            hax_labels.Position = hax.Position; 
            
            % offset the patches 
            hax_labels.Position(2)   = hax_labels.Position(2)+hax_labels_height_offset.(basin_name); 

            % colormap and number of displayed colours
            hax.CLim = c_limits;
            colormap(use_cmap);

            % add correct ticks in case of counts
            if strcmp(plot_parameter,'counts')

                % number of colours and ticks
                n_colours  = (c_limits(2)-c_limits(1))+1;
                use_c_lims = [c_limits(1)-colours_per_increment/2 ...
                              c_limits(2)+colours_per_increment/2];
                use_cmap   = centered_cmap(n_colours);
                c_ticks    = c_limits(1):c_increment:c_limits(2);

                % set everything
                colormap(use_cmap);
                hax.CLim  = use_c_lims;
                hcb.Ticks = c_ticks;

            end

            % print
            fig_name = strrep(name_dummy,'@ANOMALYTYPE@',event_type);
            print(hf,res_flag,fig_name,'-dpng');
            % close(hf);

        % for: plots for positive and negative events
        end

    % don't plot the difference for count data
    if needs_averaging

    % DIFFERENCE
    % ++++++++++

       disp(sprintf('\tdifference'));

       % data
       use_positive = strength_data.positive;
       use_negative = strength_data.negative;

       % averaging
       use_positive = nanmean(use_positive,3);
       use_negative = nanmean(use_negative,3);

       % actual data to plot
       diff_data = use_positive-use_negative;

       % PREPARATIONS
       % ++++++++++++
       
       hf  = figure;

       % want a portrait orientation for this figure
       set(hf,'Units','normalized');
       standard_position = hf.Position;
       hf.Position(3) = scale_figure_width*standard_position(3);
       hf.Position(4) = scale_figure_height*standard_position(4);

       hax = axes('XLim',x_placements,'YLim',y_placements,...
               'XGrid','on','Layer','top');

        new_font_size = floor(hax.FontSize*scale_font_size);
        set(hax,'FontSize',new_font_size);

       hold(hax,'on');

        % PLOTTING 
        % ++++++++
        
       % checkerboard, as in the dynamics analysis
       image(x_placements,y_placements,diff_data,'CDataMapping','scaled');

       colorbar(hax);

       % NINO REGIONS 
       % ++++++++++++
       
            % label boxes in a different axis
            hax_labels = axes('XLim',x_placements,'YLim',y_placements,...
                    'Visible','off','FontSize',new_font_size);
            
            hold(hax_labels,'on'); 

            for c_region = 1:length(region_names)

                x_values = [highlight_regions(c_region,1) highlight_regions(c_region,2) ...
                            highlight_regions(c_region,2) highlight_regions(c_region,1) ...
                            highlight_regions(c_region,1)];
                            
                y_values = [highlight_y_values(c_region,1) highlight_y_values(c_region,1) ...
                            highlight_y_values(c_region,2) highlight_y_values(c_region,2) ...
                            highlight_y_values(c_region,1)];
                
                h_patch = patch(x_values,y_values,region_colours(c_region,:),...
                        'EdgeColor','none'); 

            % plot in highlight regions
            end
            
        % SIGNIFICANCE 
        % ++++++++++++

            % hatch out everything that is significant
            for c_start = 1:length(time_axis)

                use_sigs   = squeeze(is_significant(c_start,:));

                % ignore NaNs and assume they are not significant
                use_sigs(isnan(use_sigs)) = false;

                sig_lons = find(use_sigs);

                % plot black crosses
                plot(hax,central_longitudes(sig_lons),ones(1,length(sig_lons)).*time_axis(c_start),...
                        'x','LineWidth',line_width_significance_outline,...
                        'MarkerSize',size_significance_marker+2,'Color',my_white);
                plot(hax,central_longitudes(sig_lons),ones(1,length(sig_lons)).*time_axis(c_start),...
                        'x','LineWidth',line_width_significance_markers,...
                        'MarkerSize',size_significance_marker,'Color',hax.XColor);

            end

       % POLISHING AND PRINTING 
       % ++++++++++++++++++++++
       
            ylabel(hax,'Start year');
            xlabel(hax,'\circ lon')

            fig_title = strrep(title_dummy,'@ANOMALYTYPE@','diff.');
            h_title = title(hax_labels,fig_title);
            set(h_title,'Visible','on'); 

            % align axes
            % axes_position       = hax_labels.Position+axes_offset;
            hax.Position        = hax.Position+axes_offset;
            hax_labels.Position = hax.Position; 
            
            % offset the patches 
            hax_labels.Position(2)   = hax_labels.Position(2)+hax_labels_height_offset.(basin_name); 

            % display colorbar
            hcb = colorbar(hax);

            % colormap and number of displayed colours
            hax.CLim = c_limits_diff;
            colormap(use_cmap_diff);

            % print
            fig_name = strrep(name_dummy,'@ANOMALYTYPE@','difference');
            print(hf,res_flag,fig_name,'-dpng');
            % close(hf);

    % if: plot difference for everything but counts
    end
