%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                               %
%   DIAGNOSE FEEDBACK LAGS FOR EACH LONGITUDE   %
%   PLOTS                                       %
%   Sub-script of the main script               %
%   Do not attempt to run alone                 %
%                                               %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

if plot_lag_values
% --------------- %
% PLOT LAG VALUES %
% --------------- %

    disp('plotting lag values')

    % PREPARATIONS 
    % ++++++++++++
    
        % need grids for pcolor
        [lon_grid,time_grid] = meshgrid(central_longitudes,double(1:12));

        % initialize figure
        hf  = figure;
        hf.Position(3) = scale_figure_width*hf.Position(3);
        hf.Position(4) = scale_figure_height*hf.Position(4);

        % initialize axes
        hax = axes('XLim',lon_cover,'YLim',[0.5 12.5],...
                'YTick',[1:1:12],'YTickLabel',months_single,...
                'XGrid','on','Layer','top');

        % additional settings: position, font size
        hax.Position = axes_position;
        hax.FontSize = floor(scale_font_size*hax.FontSize);

        hold(hax,'on');

    % PLOT 
    % ++++
        
        % checkerboard, as in the dynamics analysis
        % I definitely can't use pcolor here -- in fact, I should never
        % use it -- because it is averaging the adjacent values together
        % to produce the cell value. Hence, I'm effectively losing data,
        % and this is very much not what I want to do.
        image(lon_cover,[1 12],lag_values,...
                'CDataMapping','scaled');
        hcb = colorbar(hax,'Location','EastOutside');

    % NINO REGIONS 
    % ++++++++++++
    
        % label boxes in a different axis
        hax_labels = axes('XLim',lon_cover,'YLim',[0.5 12.5],'Visible','off');
        set(hax_labels,'Color','none','XAxisLocation','top',...
                'Position',axes_position);
        hax_labels.FontSize = hax.FontSize;
        
        hold(hax_labels,'on'); 
    
        for c_region = 1:length(region_names)

            x_values = [highlight_regions(c_region,1) highlight_regions(c_region,2) ...
                        highlight_regions(c_region,2) highlight_regions(c_region,1) ...
                        highlight_regions(c_region,1)];
                        
            y_values = [highlight_y_values(c_region,1) highlight_y_values(c_region,1) ...
                        highlight_y_values(c_region,2) highlight_y_values(c_region,2) ...
                        highlight_y_values(c_region,1)];
            
            h_patch = patch(x_values,y_values,region_colours(c_region,:),...
                    'EdgeColor','none'); 

        % plot in highlight regions
        end

    % POLISHING 
    % +++++++++
    
        xlabel(hax,'\circ lon');
        ylabel(hax,'Month');

        % align axes
        hax_labels.Position = axes_position;
        hax.Position        = axes_position;
        
        % offset the patches 
        hax_labels.Position(2) = hax_labels.Position(2)+hax_labels_height_offset.(basin_name); 
        
        % title: display it and shift the y position 
        fig_title = strrep(title_dummy,'@PLOT_TYPE@','Lags');
        h_title = title(hax_labels,fig_title);
        set(h_title,'Visible','on');
        h_title.Position(2) = title_y_position; 

        % colormap and number of displayed colours
        hax.CLim = lag_limits;
        colormap(use_cmap_lags);

        % colorbar ticks
        hcb_tick_labels          = {};
        
        for c_tick = 1:length(all_lags)
            if ( mod(c_tick,2) == 0 )
                hcb_tick_labels{c_tick} = ' '; 
            else 
                hcb_tick_labels{c_tick} = num2str(all_lags(c_tick)); 
            end 
        end
        
        set(hcb,'Ticks',c_ticks,'TickLabels',hcb_tick_labels);

        % print
        fig_name = strrep(name_dummy,'@PLOT_TYPE@','lags');
        print(hf,res_flag,fig_name,'-dpng');
        % close(hf);

% if: plot lag values
end

%  if plot_lag_feedbacks
%  % ---------------------- %
%  % PLOT PEAK CORRELATIONS %
%  % ---------------------- %
%  
%      disp('plotting peak strengths')
%  
%      % need grids for pcolor
%      [lon_grid,time_grid] = meshgrid(central_longitudes,double(1:12));
%  
%      % initialize figure
%      hf  = figure;
%      hf.Position(3) = scale_width*hf.Position(3);
%      hf.Position(4) = scale_height*hf.Position(4);
%  
%      % initialize axes
%      hax = axes('XLim',lon_cover,'YLim',[0.5 12.5],...
%                 'YTick',[],'YTickLabel','',...
%                 'XGrid','on','Layer','top');
%  
%      % additional settings: position, font size
%      hax.Position = hax.Position+axes_offset;
%      hax.FontSize = floor(font_size_scale*hax.FontSize);
%  
%      hold(hax,'on');
%  
%      % naming the regions
%      x_ticks        = [];
%      x_tick_labels  = {};
%  
%      % checkerboard, as in the dynamics analysis
%      % I definitely can't use pcolor here -- in fact, I should never
%      % use it -- because it is averaging the adjacent values together
%      % to produce the cell value. Hence, I'm effectively losing data,
%      % and this is very much not what I want to do.
%      image(lon_cover,[1 12],peak_strengths,...
%              'CDataMapping','scaled');
%      hcb = colorbar(hax,'Location','EastOutside');
%  
%      % Nino regions
%      for c_region = 1:length(region_names)
%  
%          x_values = [highlight_regions(c_region,1) highlight_regions(c_region,2) ...
%                      highlight_regions(c_region,2) highlight_regions(c_region,1) ...
%                      highlight_regions(c_region,1)];
%          y_values = [hax.YLim(1) hax.YLim(1) hax.YLim(2) hax.YLim(2) hax.YLim(1)];
%  
%          plot(x_values,y_values,'LineWidth',4,'Color',my_white);
%          plot(x_values,y_values,'LineWidth',2,'Color',region_colours(c_region,:));
%  
%          x_ticks(end+1)       = mean(highlight_regions(c_region,:));
%          x_tick_labels{end+1} = region_names{c_region};
%  
%      % plot in highlight regions
%      end
%  
%      % label boxes in a different axis
%      hax_labels = axes('XLim',lon_cover,'YLim',[1 13],...
%              'YTick',[1.5:1:12.5],'YTickLabel',months_single);
%      set(hax_labels,'Color','none','XAxisLocation','top',...
%              'Position',hax.Position);
%      hax_labels.FontSize = hax.FontSize;
%  
%      % polishing
%      xlabel(hax,'\circ lon');
%      ylabel(hax_labels,'Month');
%  
%      fig_title = strrep(title_dummy,'@PLOT_TYPE@','peak strength');
%      title(hax_labels,fig_title);
%  
%      % align axes
%      axes_position = hax_labels.Position;
%  
%      hax_labels.Position = axes_position;
%      hax.Position        = axes_position;
%  
%      % colormap and number of displayed colours
%      % for correlation
%      if ( analysis_id == 1 )
%          hax.CLim = [-1 1];
%          n_colors = 21;
%      % for regression
%      else
%          hax.CLim = [-strength_limits.(reference_name) strength_limits.(reference_name)];
%          n_colors = strength_colors.(reference_name);
%      end
%  
%      % set colormap
%      colormap(centered(n_colors));
%  
%      % display region names
%      set(hax_labels,'XTick',x_ticks,'XTickLabel',x_tick_labels);
%  
%      % print
%      fig_name = strrep(name_dummy,'@PLOT_TYPE@','peak_strengths');
%      print(hf,res_flag,fig_name,'-dpng');
%      % close(hf);
%  
%  % if: plot peak feedback_strengths
%  end
%  
%  if plot_all_strengths
%  % ---------------------- %
%  % PLOT PEAK CORRELATIONS %
%  % ---------------------- %
%  for c_lag = 1:n_lags
%  
%      lag = all_lags(c_lag);
%      disp(sprintf('plotting correlation for lag %d',lag));
%  
%      % need grids for pcolor
%      [lon_grid,time_grid] = meshgrid(central_longitudes,double(1:12));
%  
%      % initialize figure
%      hf  = figure;
%      hf.Position(3) = scale_width*hf.Position(3);
%      hf.Position(4) = scale_height*hf.Position(4);
%  
%      % initialize axes
%      hax = axes('XLim',lon_cover,'YLim',[0.5 12.5],...
%                 'YTick',[],'YTickLabel','',...
%                 'XGrid','on','Layer','top');
%  
%      % additional settings: position, font size
%      hax.Position = hax.Position+axes_offset;
%      hax.FontSize = floor(font_size_scale*hax.FontSize);
%  
%      hold(hax,'on');
%  
%      % naming the regions
%      x_ticks        = [];
%      x_tick_labels  = {};
%  
%      % checkerboard, as in the dynamics analysis
%      % I definitely can't use pcolor here -- in fact, I should never
%      % use it -- because it is averaging the adjacent values together
%      % to produce the cell value. Hence, I'm effectively losing data,
%      % and this is very much not what I want to do.
%      image(lon_cover,[1 12],squeeze(feedback_strengths(:,:,c_lag)'),...
%              'CDataMapping','scaled');
%      hcb = colorbar(hax,'Location','EastOutside');
%  
%      % Nino regions
%      for c_region = 1:length(region_names)
%  
%          x_values = [highlight_regions(c_region,1) highlight_regions(c_region,2) ...
%                      highlight_regions(c_region,2) highlight_regions(c_region,1) ...
%                      highlight_regions(c_region,1)];
%          y_values = [hax.YLim(1) hax.YLim(1) hax.YLim(2) hax.YLim(2) hax.YLim(1)];
%  
%          plot(x_values,y_values,'LineWidth',4,'Color',my_white);
%          plot(x_values,y_values,'LineWidth',2,'Color',region_colours(c_region,:));
%  
%          x_ticks(end+1)       = mean(highlight_regions(c_region,:));
%          x_tick_labels{end+1} = region_names{c_region};
%  
%      % plot in highlight regions
%      end
%  
%      % label boxes in a different axis
%      hax_labels = axes('XLim',lon_cover,'YLim',[1 13],...
%              'YTick',[1.5:1:12.5],'YTickLabel',months_single);
%      set(hax_labels,'Color','none','XAxisLocation','top',...
%              'Position',hax.Position);
%      hax_labels.FontSize = hax.FontSize;
%  
%      % polishing
%      xlabel(hax,'\circ lon');
%      ylabel(hax_labels,'Month');
%  
%      fig_title = strrep(title_dummy,'@PLOT_TYPE@',sprintf('Lag %d strengths.',lag));
%      title(hax_labels,fig_title);
%  
%      % align axes
%      axes_position = hax_labels.Position;
%  
%      hax_labels.Position = axes_position;
%      hax.Position        = axes_position;
%  
%      % colormap and number of displayed colours
%      % for correlation
%      if ( analysis_id == 1 )
%          hax.CLim = [-1 1];
%          n_colors = 21;
%      % for regression
%      else
%          hax.CLim = [-strength_limits.(reference_name) strength_limits.(reference_name)];
%          n_colors = strength_colors.(reference_name);
%      end
%  
%      % colormap
%      colormap(centered(n_colors));
%  
%      % display region names
%      set(hax_labels,'XTick',x_ticks,'XTickLabel',x_tick_labels);
%  
%      % print
%      fig_name = strrep(name_dummy,'@PLOT_TYPE@',sprintf('lag_%d_strengths',lag));
%      print(hf,res_flag,fig_name,'-dpng');
%      % close(hf);
%  
%  % for: plot all feedback_strengths
%  end
%  
%  % if: plot all feedback_strengths
%  end
