%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                        %
%   DIAGNOSE FEEDBACK LAGS FOR EACH LONGITUDE            %
%   SETTINGS: CALCULATION FOR A GIVEN FEEDBACK ELEMENT   %
%   Plotting is done in plot_lagged_feedbacks.m          %
%                                                        %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Equatorial indices at lag 0 can be calculated with
% zonal_feedback_strengths_seasonal_regressions.m

% ----- %
% BASIC %
% ----- %

    % if you whish to run the script only once,
    % specify the single_mode flag in the settings,
    % which will set the basin_name, reference_name,
    % lag_name, and analysis_type

    % maximum lag in months
    if strcmp(basin_name,'Atlantic')
        maximum_lag = 8;
    else
        maximum_lag = 8;
    end

    % bundle up variables
    all_vars = {reference_name,lag_name};

    % significance test
    alpha_value = 0.1;

% ----- %
% FLAGS %
% ----- %

    perform_calculations   = false;
        load_data                    = perform_calculations;
        calculate_feedback_strengths = perform_calculations;
        save_lagged_indices          = perform_calculations;
    plot_lag_values    = true;
    plot_lag_feedbacks = false;
    plot_all_strengths = false;

    % is wind one of the variables?
    wind_var = 'ustr';
    all_vars = {reference_name,lag_name};

    contains_wind =  strcmp({all_vars{:}},wind_var);
    analyse_wind  = ( sum(contains_wind) ~= 0 );

% ----- %
% OTHER %
% ----- %

    % assign an ID to the analysis type
    % assign additional analysis-type dependent
    if strcmp(analysis_type,'acc')
        analysis_id  = 1;
        analysis_title = 'ACC';
    elseif strcmp(analysis_type,'reg')
        analysis_id  = 2;
        analysis_title = 'regression';
    elseif strcmp(analysis_type,'rreg')
        analysis_id  = 3;
        analysis_title = 'robust reg.';
    else
        error(['>',analysis_type,'< is not a valid method ',...
               'to diagnose the feedback strength. Choose ',...
               'either of acc, reg, or rreg.']);
    end

% ----- %
% FILES %
% ----- %

    file_path = ['/mnt/lustre01/work/bm0764/b350066/data/zonal_equatorial_analysis/'];
    file_dummy   = [file_path,...
                    'equatorial_indices_',num2str(start_year),'-',num2str(stop_year),'_',...
                    basin_name,'_@DATASET_NAME@-@VAR_NAME@.mat'];

    out_file  = [file_path,...
                 'lagged_indices_',analysis_type,'_',...
                 num2str(start_year),'-',num2str(stop_year),'_',...
                 basin_name,'_',...
                 all_data.(reference_name),'-',reference_name,'_',...
                 all_data.(lag_name),'-',lag_name,'.mat'];

% -------- %
% PLOTTING %
% -------- %

    % GENERAL
    % +++++++

        atlantic_asymmetric_bjf_plot_settings;

        % axes fine tuning
%          x_axes_offset      = 0;
%          y_axes_offset      = 0.035;
%          width_axes_offset  = -0.035;
%          height_axes_offset = -0.06;
        axes_position      = axes_position+...
                [x_axes_offset y_axes_offset width_axes_offset height_axes_offset];

        % resolution
        res_flag = '-r200';

    % COLOURS
    % +++++++

        % which colour map to actually use
        black_half    = gray(maximum_lag+2);
        coloured_half = flipud(plasma(maximum_lag+1));

        use_cmap_lags = [black_half(2:maximum_lag+1,:); coloured_half];
        
    % THE NINO BOXES 
    % ++++++++++++++
    
        % height offset for the offset for the hax_labels 
        hax_labels_height_offset = struct('Atlantic',0.035,'Pacific',0.057);    % units: y label values, have to set this 
        
        % new y position of the title, in units of the y axis 
        title_y_position = 12.75; 

    % LIMITS ETC
    % ++++++++++

        % colour limits for lag analysis
        lag_limits    = [-maximum_lag maximum_lag];

        % colorbar ticks: should be in the middle of the box
        % ticks are shifted against one by 1/2/lag_max
        c_tick_shift     = 0.5/maximum_lag;
        colour_increment = 1-c_tick_shift;
        c_ticks_single   = 0:colour_increment:maximum_lag;
        c_ticks          = [fliplr(-c_ticks_single(2:end)) c_ticks_single];

        % colour limits and levels for feedback strengths
        strength_limits    = struct('ssh',30,'sst',0.05,'ustr',7);
        strength_colors    = struct('ssh',30,'sst',30,'ustr',28);

    % NAMING ETC
    % ++++++++++

        % naming
        % title_dummy = [basin_name,' ',upper(reference_name),'-',upper(lag_name),' ',...
        %               analysis_type,' @PLOT_TYPE@, ',...
        %               num2str(start_year),'-',num2str(stop_year)];
        title_dummy = [basin_name,' ',upper(reference_name),'-',upper(lag_name)];

        name_dummy = [basin_name,'_@PLOT_TYPE@_',analysis_type,'_',...
                      all_data.(reference_name),'-',reference_name,'_',...
                      all_data.(lag_name),'-',lag_name,'_',...
                      num2str(start_year),'-',num2str(stop_year),'.png'];

        % month shorts
        months_single = {'J','F','M','A','M','J','J','A','S','O','N','D'};

% ------------- %
% MISCELLANEOUS %
% ------------- %

    % define analysis region
    divert_south = false;
    zonal_analysis_region_definition;

    % font size
    font_size_scale = 2.5;

    % mute warning from robust regression
    % query the last warning, including it's ID with
    % w = warning('query','last').
    warn_id = 'stats:statrobustfit:IterationLimit';
