%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                          %
%   DIAGNOSE FEEDBACK LAGS FOR EACH LONGITUDE              %
%   WRAPPER: CALCULATION FOR A GIVEN FEEDBACK ELEMENT      %
%   Main: diagnose_zonal_feedback_lengths.m                %
%   Settings: diagnose_zonal_feedback_lengths_settings.m   %
%   Plots: diagnose_zonal_feedback_lengths_plots.m         %
%                                                          %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

clear all;
close all;
clc;

addpath('/mnt/lustre01/pf/b/b350066/scripts/matlab/general/useful');

% script-dividing flags are in the wrapper such that
% the main script and the settings are usable on their own as well

% independent of single mode or bulk mode

% ---------------- %
% GENERAL SETTINGS %
% ---------------- %

    % loop over all pairs of feedbacks, basins, and anaylsis methods
    all_reference_names = {'ssh','sst','ustr'};
    all_lag_names       = {'sst','ustr','ssh'};

    % datasets
    all_data   = struct('sst', 'ersst',...
                        'ustr','era_sfcstress',...
                        'ssh', 'aviso');

    % basins
    all_basins = {'Atlantic','Pacific'};

    % analysis type: anomaly correlation (acc), normal linear regression
    % (reg), or obust regression (rreg)?
    all_analysis = {'rreg'}; % {'acc','reg','rreg'};

    % time constraints
    start_year = 1993;
    stop_year  = 2012;

% -------------------- %
% SETTING CONSEQUENCES %
% -------------------- %

    n_feedbacks = length(all_reference_names);
    n_basins    = length(all_basins);
    n_analysis  = length(all_analysis);

% ---------------------------------------- %
% CALL MAIN SCRIPTS WITH VARIABLE SETTINGS %
% ---------------------------------------- %

    for c_basin = 1:n_basins

        basin_name = char(all_basins{c_basin});

        for c_feedback = 1:n_feedbacks

            reference_name = char(all_reference_names{c_feedback});
            lag_name       = char(all_lag_names{c_feedback});

            for c_analysis = 1:n_analysis

                analysis_type = char(all_analysis{c_analysis});

                % actual call of the script
                diagnose_zonal_feedback_lags;

            % for: loop over all analysis types
            end

        % for: loop over all feedbacks
        end

    % for: basins
    end
