%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                 %
%    STRENGTH OF LAGGED BJERKNES FEEDBACK ELEMENTS                %
%    VARIABLE ANALYSIS TYPE: ACC, REGRESSION, ROBUST REGRESSION   %
%    SETTINGS                                                     %
%                                                                 %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% ------- %
% GENERAL %
% ------- %

    % DEFINED IN THE WRAPPER:
    %     reference_name, lag_name, all_data
    %     basin_name
    %     analysis_type
    %     start_year, stop_year

    % sensitivity between which two variables?
    % associated datasets?
    all_vars = {reference_name,lag_name};

    % which variable is the wind variable?
    wind_var = 'ustr';

    % define analysis region
    divert_south = false;
    zonal_analysis_region_definition;

    % which types of anomalies?
    % -1 for negative 1 for positive, 0 for all
    all_anomalies = [-1 1];

    % bootstrapping and significance test
    n_bootstraps = 1000;
    alpha        = 0.1;

% ----- %
% FLAGS %
% ----- %

    load_data            = false;
        perform_calculations = load_data;
        save_data            = load_data;
    load_previous_data   = ~load_data;
    produce_plots        = true;

    % use positive lags only?
    use_positive_lags_only = false;

    % do the analysis variables contain a wind variable?
    contains_wind =  strcmp({all_vars{:}},wind_var);
    analyse_wind  = ( sum(contains_wind) ~= 0 );

% --------------- %
% PATHS AND FILES %
% --------------- %

    path   = ['<path where data for zonal analysis is stored>'];

    infile = [path,...
              'lagged_indices_',analysis_type,'_',...
              num2str(start_year),'-',num2str(stop_year),'_',...
              basin_name,'_',...
              all_data.(reference_name),'-',reference_name,'_',...
              all_data.(lag_name),'-',lag_name,'.mat'];

    outfile = [path,...
               'lagged_feedback_strengths_',analysis_type,'_',...
               num2str(start_year),'-',num2str(stop_year),'_',...
               basin_name,'_',...
               all_data.(reference_name),'-',reference_name,'_',...
               all_data.(lag_name),'-',lag_name,'.mat'];

% ----- %
% OTHER %
% ----- %

    % assign an ID to the analysis type
    % assign additional analysis-type dependent
    if strcmp(analysis_type,'acc')
        analysis_id  = 1;
        analysis_title = 'ACC';
    elseif strcmp(analysis_type,'reg')
        analysis_id  = 2;
        analysis_title = 'regression';
    elseif strcmp(analysis_type,'rreg')
        analysis_id  = 3;
        analysis_title = 'robust reg.';
    else
        error(['>',analysis_type,'< is not a valid method ',...
               'to diagnose the feedback strength. Choose ',...
               'either of acc, reg, or rreg.']);
    end

% -------- %
% PLOTTING %
% -------- %

    % GENERAL
    % +++++++

        atlantic_asymmetric_bjf_plot_settings;

        % fine tune axes
        axes_position = axes_position+...
                [x_axes_offset y_axes_offset width_axes_offset height_axes_offset];

    % THE NINO BOXES
    % ++++++++++++++

        % height offset for the offset for the hax_labels
        hax_labels_height_offset = struct('Atlantic',0.035,'Pacific',0.057);    % units: y label values, have to set this

    % LIMITS ETC
    % ++++++++++

        % colour limits and levels, colormap, colorbar settings
        % for correlations:
        if ( analysis_id == 1 )

            c_limits  = [-1 1];
            n_colours = 20;

        % regressions
        else

            all_c_limits     = struct('ssh',[-25 45],'sst',[-0.03 0.05],'ustr',[-7 12]);  % ssh: 30
            all_c_increment  = struct('ssh',2,'sst',0.005,'ustr',1);
            all_n_colours    = struct('ssh',27,'sst',30,'ustr',48);   % ssh: 30
            all_grey_offsets = struct('ssh',4,'sst',2,'ustr',3);

            % what to use?
            c_limits    = all_c_limits.(reference_name);
            c_increment = all_c_increment.(reference_name);
            grey_offset = all_grey_offsets.(reference_name);

        end

    % COLOURMAP
    % +++++++++

        % grey half: omit the lightest third
        n_grey          = length(c_limits(1):c_increment:-c_increment);  % this is the actual number of greys I want to have
        n_grey_complete = floor(3*n_grey/2);                     % this is what the colormap gets to omit the bright parts

        grey_part = gray(n_grey_complete);
        grey_part = flipud(grey_part(grey_offset:n_grey+grey_offset,:));   % here, the darkest patch and the brightest colours are omitted

        % coloured part: one extra entry. to omit the pure white at the beginning
        % I need the pure white at the lower end of the colour bar to signify NaNs
        n_coloured = length(0:c_increment:c_limits(2));

        coloured_part = plasma(n_coloured+1);

        % complete colour map -- omit white entry of coloured part
        use_cmap = [grey_part; coloured_part(2:end,:)];

        % set first entry of grey map to white to accomodate NaNs
        use_cmap(1,:) = [1 1 1];

    % NAMING
    % ++++++

        % short title for publication
        title_dummy = ['@ANOMALYTYPE@ ',upper(reference_name),'-',upper(lag_name)];

        name_dummy = ['lagged_',basin_name,'_',...
            reference_name,'-',lag_name,'_',...
            all_data.(reference_name),'-',all_data.(lag_name),'_',...
            analysis_type,'_feedback_strengths_@ANOMALYTYPE@_',...
            num2str(start_year),'-',num2str(stop_year),'.png'];

    % OTHER
    % +++++

        res_flag        = '-r200';

% ------------- %
% MISCELLANEOUS %
% ------------- %

    % month shorts
    months_single = {'J','F','M','A','M','J','J','A','S','O','N','D'};

    % mute warning from robust regression
    % query the last warning, including it's ID with
    % w = warning('query','last').
    warn_id = 'stats:statrobustfit:IterationLimit';
