%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                         %
%   ZONAL VARIATIONS IN ENSO PROPERTIES   %
%   DEFINITION OF ANALYSIS REGIONS        %
%                                         %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% ------------------------ %
% BASIN-DEPENDENT SETTINGS %
% ------------------------ %

    if strcmp(basin_name,'Pacific')

        % total zonal extent
        lon_cover = [160 280];

        % % which latitudinal and longitudinal extent should the boxes have?
        % % total extent is twice this value
        lat_extent  = 2;

        % % longitudinal extent
        lon_extent  = 2;

        % longitudinal steph width, i.e. how far are the
        % boxes apart longitudinally
        delta_lon = 1;

        % curve the central latitude away from the equator to the south
        % to account for the southward propagation of ENSO signals
        % in the far east
        % where does the branching off start?
        departure_lon = 265;

        % what is the farthest south the branching off should reach?
        departure_maximum_lat = -7.5;

    % Atlantic
    else

        % total extent
        lon_cover = [-40 10];

        lat_extent            = 2;
        lon_extent            = 2;

        delta_lon             = 1;

        departure_lon         = 0;
        departure_maximum_lat = -15;

    end

    % use equatorial data only?
    % replace the diversion longitudes and latitudes in this case
    if ~divert_south
        departure_lon         = lon_cover(2)-delta_lon;
        departure_maximum_lat = -0.001;
    end

% -------------------------- %
% DEFINE CENTRAL COORDINATES %
% -------------------------- %

    central_longitudes = [lon_cover(1):delta_lon:(lon_cover(2))];

    central_latitudes = zeros(size(central_longitudes));

    % where should the centers be off-equatorial?
    is_off_equatorial = ( central_longitudes > departure_lon );
    extent_off        = sum(is_off_equatorial);

    % linearly depart from the equator
    delta_lat = departure_maximum_lat/extent_off;

    % assign the branching off
    central_latitudes(is_off_equatorial) = ...
            [delta_lat:delta_lat:departure_maximum_lat];
