%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                           %
%   ZONAL DISTRIBUTION OF ENSO PROPERTIES AND ASYMMETRIES   %
%   MAIN                                                    %
%                                                           %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

clc;
close all;

zonal_enso_properties_settings;

if load_data
    clear all;
    zonal_enso_properties_settings;
end

if load_data
% --------- %
% LOAD DATA %
% --------- %

    disp('loading and cropping data');

    % loading
    data  = load(in_file);
    grids = load(grid_file);

% if: load data
end

if perform_calculations
% -------------------- %
% CALCULATE PARAMETERS %
% -------------------- %

    % storage
    event_data       = struct();
    index_parameters = struct();
    is_different     = struct();

    textprogressbar('calculating event parameters: ');
    for c_lon = 1:length(central_longitudes)

        textprogressbar(c_lon/length(central_longitudes)*100);

        % CALCULATE INDEX
        % +++++++++++++++

            % specify the box
            use_lon = central_longitudes(c_lon);
            use_lat = central_latitudes(c_lon);

            lon_bounds = [(use_lon-lon_extent) (use_lon)+lon_extent];
            lat_bounds = [(use_lat-lat_extent) (use_lat+lat_extent)];

            % calculate index
            index = calcIndexAveraged(data.monthly_mean,...
                    grids.(dataset_name).lat_grid,grids.(dataset_name).lon_grid,...
                    grids.(dataset_name).grid_box_area,...
                    lat_bounds,lon_bounds);

            % CALCULATE ANOMALIES
            % +++++++++++++++++++

                % anomalies
                [anomalies,date_vector] = calcAnomalies(...
                        index,data.date_vector,start_year,stop_year);

                % overall parameters: stddev, skewness, kurtosis
                index_parameters.stddev(c_lon) = std(anomalies);
                index_parameters.skew(c_lon)   = skewness(anomalies);
                index_parameters.kurt(c_lon)   = kurtosis(anomalies);

            % identification of positive and negative events and anomalies
            for event_type = [1 -1]

                % naming
                if ( event_type == 1 )
                    type_string = 'positive';
                else
                    type_string = 'negative';
                end

                % IDENTIFY EVENTS AND STORE DATA
                % ++++++++++++++++++++++++++++++

                    if calculate_events

                        [l,g,d,dates,p,m] = eventLengths(...
                                anomalies,date_vector,t_id,event_type);

                        % swap strength data to have ninos and ninas of
                        % the same magnitude
                        p = abs(p);

                        % constrain analysis to season
                        is_events = ismember(dates(:,2),season_def);

                        % throw away all events that are not in the events
                        l = l(is_events);
                        p = p(is_events);

                        % store parameters
                        % how many events in total?
                        n_events = length(l);

                        event_data.events.(type_string).n_events(c_lon)             = n_events;
                        event_data.events.(type_string).lengths(c_lon,1:n_events)   = l;
                        event_data.events.(type_string).strengths(c_lon,1:n_events) = p;

                    % if: calculate event data
                    end

                    % base significance test on all anomalies to increase the
                    % data pool
                    if calculate_anomalies

                        is_anomaly = ( sign(anomalies) == sign(event_type) );

                        % strengths and dates
                        p     = abs(anomalies(is_anomaly));
                        dates = data.date_vector(is_anomaly,:);

                        % dummy lengths -- not possible to diagnose with
                        % all anomalies
                        l = zeros(size(p));

                        % constrain analysis to season
                        is_events = ismember(dates(:,2),season_def);

                        % throw away all events that are not in the events
                        l = l(is_events);
                        p = p(is_events);

                        % store parameters
                        % how many events in total?
                        n_events = length(l);

                        event_data.anomalies.(type_string).n_events(c_lon)             = n_events;
                        event_data.anomalies.(type_string).lengths(c_lon,1:n_events)   = l;
                        event_data.anomalies.(type_string).strengths(c_lon,1:n_events) = p;

                    % if: calculate anomaly data
                    end

            % for: calculate parameters for positive and negative events
            end

    % for: calculate parameters for all longitudes
    end
    textprogressbar('');

    % SIGNIFICANT DIFFERENCE?
    % +++++++++++++++++++++++

        disp('significance testing');

        % clean up anomalies and/or event data
        for use_data = {all_data{:}}

            use_data = char(use_data);

            % clean up missing values and significance testing
            for event_type = [-1 1]

                % naming
                if ( event_type == 1 )
                    type_string = 'positive';
                else
                    type_string = 'negative';
                end

                for parameter = {'lengths','strengths'}
                    parameter = char(parameter);
                    is_missing = ( event_data.(use_data).(type_string).(parameter) == 0);
                    event_data.(use_data).(type_string).(parameter)(is_missing) = NaN;
                end

            end

            % test difference in means for the two parameters
            for c_lon = 1:length(central_longitudes)

                for test_parameter = {'lengths','strengths'}

                    test_parameter = char(test_parameter);

                    use_positive = event_data.(use_data).positive.(test_parameter)(c_lon,:);
                    use_negative = event_data.(use_data).negative.(test_parameter)(c_lon,:);

                    % exclude NaNs
                    use_positive(isnan(use_positive)) = [];
                    use_negative(isnan(use_negative)) = [];

                    % perform the test
                    reject_h0 = ttest2(use_positive,use_negative,...
                            'Alpha',alpha,'Vartype','unequal');

                    % save the decision
                    is_different.(use_data).(test_parameter)(c_lon) = reject_h0;

                % for: significant differences for lengths, strengths parameters
                end

            % for: signifiat differences between positive and negative events
            end

        % for: significance testing for anomaly and event data
        end

% if: perform calculations
end

if produce_plots
% ------------ %
% PLOT RESULTS %
% ------------ %

%      % INDEX PARAMETERS
%      % ++++++++++++++++
%
%          hf  = figure;
%          hax = axes('XLim',lon_cover,'YLim',y_limit_index);
%
%          hold(hax,'on');
%          legend_entries = [];
%          legend_labels  = {};
%
%          % plot background regions
%          for c_region = 1:size(highlight_regions,1)
%
%              use_region = highlight_regions(c_region,:);
%              use_colour = region_colours(c_region,:);
%
%              % define the polygon edges
%              x_values = [use_region(1) use_region(2) ...
%                      use_region(2) use_region(1) use_region(1)];
%              y_values = [y_limit_index(1) y_limit_index(1) ...
%                      y_limit_index(2) y_limit_index(2) y_limit_index(1)];
%
%              % plot them
%              legend_entries(end+1) = fill(x_values,y_values,use_colour,...
%                      'FaceColor',use_colour,'EdgeColor','none',...
%                      'FaceAlpha',alpha_regions);
%
%              legend_labels{end+1} = char(region_names{c_region});
%
%          end
%
%          % plot parameters
%          for parameter = {index_properties{:}}
%
%              parameter = char(parameter);
%
%              % identify which data to plot, and how
%              use_parameter = index_parameters.(parameter);
%              use_colour    = index_colours.(parameter);
%
%              % "normalize" the data to plot it all into a single panel
%              use_parameter = use_parameter-mean(use_parameter);
%              use_parameter = use_parameter./std(use_parameter);
%
%              % plot the data
%              plot(central_longitudes,use_parameter,...
%                      'LineWidth',4,'Color',my_white);
%              legend_entries(end+1) = plot(central_longitudes,use_parameter,...
%                      'LineWidth',2,'Color',use_colour);
%
%              % legend label
%              legend_labels{end+1} = parameter_names.(parameter);
%
%          end
%
%          % finish plot
%          grid(hax,'on');
%          hold(hax,'off');
%          set(hax,'XLim',lon_cover);
%
%          title([basin_name,' overall index parameters, ',...
%                  num2str(start_year),'-',num2str(stop_year)]);
%          ylabel('Normalized parameter');
%          xlabel('Central longitude');
%
%          % legend
%          legend(legend_entries,legend_labels,...
%                  'Location','SouthEastOutside',...
%                  'Box','off');
%
%          % print
%          fig_title = ['zonal_index_parameters_',basin_name,'_',...
%                  num2str(start_year),'-',num2str(stop_year),'.png'];
%
%          print(hf,fig_title,'-dpng');
%          close(hf);

    % EVENT PARAMETERS
    % ++++++++++++++++

        for parameter = {'strengths'}; % 'n_events','lengths'

            parameter = char(parameter);
            disp(sprintf('plotting %s',parameter));

            % SET UP FIGURE AND AXES
            % ++++++++++++++++++++++

                hf = figure;

                % scale the height
                hf.Units = 'normalized';
                hf.Position(3) = scale_figure_width*hf.Position(3);
                hf.Position(4) = scale_figure_height*hf.Position(4);

                % label boxes in a different axis
                hax_labels = axes('XLim',lon_cover,'XAxisLocation','top',...
                        'YAxisLocation','right');

                % font size
                hax_labels.FontSize = ceil(font_size_scale*hax_labels.FontSize);

                % plotting axes
                hax = axes('XLim',lon_cover,'YLim',y_limits,'Color','none',...
                        'FontSize',hax_labels.FontSize);
                hold(hax,'on');

                if overlay_counts
                    hold(hax_labels,'on');
                else
                    set(hax_labels,'YLim',hax.YLim,'YTickLabel',[]);
                end

                % naming the regions
                x_ticks        = [];
                x_tick_labels  = {};

                % legend
                legend_entries = [];
                legend_labels  = {};

                % plot the regions
                for c_region = 1:size(highlight_regions,1)

                    use_region = highlight_regions(c_region,:);
                    use_colour = region_colours(c_region,:);

                    % define the polygon edges
                    x_values = [use_region(1) use_region(2) ...
                            use_region(2) use_region(1) use_region(1)];
                    y_values = [y_limits(1) y_limits(1) ...
                            y_limits(2) y_limits(2) y_limits(1)];

                    plot(hax,x_values,y_values,'LineWidth',4,'Color',my_white);
                    plot(hax,x_values,y_values,'LineWidth',2,'Color',region_colours(c_region,:));

                    x_ticks(end+1)       = mean(highlight_regions(c_region,:));
                    x_tick_labels{end+1} = region_names{c_region};

                end

                % set region names
                set(hax_labels,'XTick',x_ticks,'XTickLabel',x_tick_labels);

            % IDENTIFY DATA AND PLOT IT
            % +++++++++++++++++++++++++

                for use_data  = {all_data{:}};

                    use_data = char(use_data);

                    for type_string = {'positive','negative'};

                        type_string = char(type_string);
                        use_colour  = colour_chart.(use_data).(type_string);

                        % identify data and plotting colour
                        parameter_data = event_data.(use_data).(type_string).(parameter);

                        % need averaging? significance data present?
                        sample_distributions = ...
                                ( ( size(parameter_data,1) > 1 ) & ...
                                  ( size(parameter_data,2) > 1 ) );

                        if sample_distributions
                             parameter_data = nanmean(parameter_data,2);
                        end

                        % overlay counts
                        if overlay_counts
                            plot(hax_labels,central_longitudes,...
                                    event_data.(use_data).(type_string).n_events,...
                                    'LineWidth',2,'Color',colour_chart.anomalies.(type_string));
                        end

                        % actual strength data
                        plot(hax,central_longitudes,parameter_data,...
                                'LineWidth',4,'Color',my_white);
                        legend_entries(end+1) = plot(hax,...
                                central_longitudes,parameter_data,...
                                'LineWidth',2,'Color',use_colour);
                        % legend_labels{end+1} = ...
                        %         sprintf([upper(type_string(1)),type_string(2:end),...
                        %          '\n',use_data]);
                        legend_labels{end+1} = ...
                                sprintf([upper(type_string(1)),type_string(2:end)]);

                        % significance?
                        if sample_distributions & show_significance

                            is_significant = find(is_different.(use_data).(parameter));

                            plot(hax,central_longitudes(is_significant),...
                                    parameter_data(is_significant),...
                                    'o','MarkerSize',6,...
                                    'MarkerFaceColor',use_colour,...
                                    'MarkerEdgeColor',use_colour);

                        end

                    % for: plot positive and negative data
                    end

                % for: plot anomalies and events
                end

            % FINISH PLOT
            % +++++++++++

                hold(hax,'off');
                grid(hax,'on');
                set(hax,'XLim',lon_cover);

                if overlay_counts
                    hold(hax_labels,'off');
                end

                if poster_plots
                    fig_title = poster_title;
                else
                    fig_title = strrep(title_dummy,'@PARAMETER@',parameter_names.(parameter));
                end

                title(hax_labels,fig_title);
                xlabel(hax,'Central longitude');
                ylabel(hax,'SST strength');

                hl = legend(hax,legend_entries,legend_labels,...
                        'Location','SouthOutside',...
                        'Box','off','Orientation','horizontal',...
                        'FontSize',hax_labels.FontSize);

                % align axes
                common_axes_position = hax_labels.Position+axes_offset;
                set(hax_labels,'Position',common_axes_position);
                set(hax,'Position',common_axes_position);

                % set horizontal position of legend for large font sizes
                if font_size_scale > 1 & legend_horizontal_position ~= 0.0
                    hl.Position(1) = legend_horizontal_position;
                end

                % print
                fig_title = strrep(name_dummy,'@PARAMETER@',parameter);

                print(hf,print_res,fig_title,'-dpng');
                % close(hf);

    % for: plot length and strength data
    end

% if: produce plots
end
